# cmaptools
A set of functions to analyze and fix bad colormaps

## Installation

You can install with `pip`:

    pip install cmaptools


## Documentation

Coming soon!
For now check: Evaluate and compare colormaps, an [SEG Geophysical tutorial](https://github.com/seg/tutorials-2014#august-2014)

